==> ReleaseV1.1.0.tar.gz: winginterfacelibrary/src/Interface/IReportService.cs <==
﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DTO.Share;
using WingInterfaceLibrary.Request.Record;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 报告服务
    /// </summary>
    /// <value>报告</value>
    /// <example>报告服务API</example>
    [System.ComponentModel.Description("WingReportService")]
    public interface IReportService
    {
        /// <summary>
        /// 查询报告模板详情
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告模板详情</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<ReportTemplateDTO> FindReportTemplateByCodeAsync(FindReportTemplateByCodeRequest request);

        /// <summary>
        /// 查询报告详情
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告详情</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<ReportDTO> FindReportByCodeAsync(FindReportByCodeRequest request);

        /// <summary>
        /// 查询检查关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<List<ReportDTO>> FindExamReportsAsync(FindExamReportsRequest request);

        /// <summary>
        /// 查询病人关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<List<ReportDTO>> FindPatientReportsAsync(FindPatientReportsRequest request);

        /// <summary>
        /// 查询报告标签配置
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告标签配置集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,RecordNotExistError</errorCodes>
        Task<List<ReportLabelDTO>> FindReportLabelsAsync(FindReportLabelsRequest request);

        /// <summary>
        /// 根据分享短码查询分享内容
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>分享记录</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<ShareDTO> FindShareContentAsync(FindShareContentRequest request);

        /// <summary>
        /// 创建报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,RecordNotExistError,ReportTemplateJsonEmpty,ReportDatasJsonEmpty,AddReportFailed,ReferralRecordNotExisted,ReferralRecordNeverAccepted</errorCodes>
        Task<string> AddReportAsync(AddReportRequest request);

        /// <summary>
        /// 修改报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,RecordNotExistError,ReportTemplateJsonEmpty,ReportDatasJsonEmpty,ReferralRecordNotExisted,ReferralRecordNeverAccepted</errorCodes>
        Task<bool> ModifyReportAsync(ModifyReportRequest request);

        /// <summary>
        /// 修改报告标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty</errorCodes>
        Task<bool> ModifyReportLabelsAsync(ModifyReportLabelsRequest request);

        /// <summary>
        /// 分享报告-短信
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,MobileListEmpty,MessageUrlEmpty,ReportPageNeverConfig,ReportSMSTempalteNeverConfig,CreateShareCodeError</errorCodes>
        Task<bool> ShareReportBySmsAsync(ShareReportBySmsRequest request);

        /// <summary>
        /// 分享报告-邮件
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,EmailListEmpty,MessageUrlEmpty,ReportPageNeverConfig,ReportSMSTempalteNeverConfig</errorCodes>
        Task<bool> ShareReportByEmailAsync(ShareReportByEmailRequest request);

        /// <summary>
        /// 拷贝成个人报告模板
        /// </summary>
        /// <returns>模版编码</returns>
        Task<string> CopyPersonalReportTemplateAsync(CopyReportTemplateRequest request);

        /// <summary>
        /// 拷贝成机构报告模板
        /// </summary>
        /// <returns>模版编码</returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<string> CopyOrgReportTemplateAsync(CopyOrgReportTemplateRequest request);

        /// <summary>
        /// 获取报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> GetReportTemplatePageAsync(FindReportTemplatePagesRequest request);

        /// <summary>
        /// 获取机构报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<PageResult<ReportTemplateDTO>> GetOrgReportTemplatePageAsync(FindReportTemplatePagesRequest request);

        /// <summary>
        /// 添加报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>JsonError,AuthenticationError,UserOrganizationCodeEmpty,ReportTemplateNameDuplication</errorCodes>
        Task<string> AddReportTemplateAsync(AddReportTemplateRequest request);

        /// <summary>
        /// 更新报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateReportTemplateAsync(UpdateReportTemplateRequest request);

        /// <summary>
        /// 删除报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ReportTemplateCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> RemoveReportTemplateAsync(RemoveReportTemplateRequest request);

        /// <summary>
        /// 添加机构报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,UserOrganizationCodeEmpty,ReportTemplateNameDuplication</errorCodes>
        Task<string> AddOrgReportTemplateAsync(AddReportTemplateRequest request);

        /// <summary>
        /// 删除机构报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ReportTemplateCodeEmpty,UserNotDirector,AuthenticationError</errorCodes>
        Task<bool> RemoveOrgReportTemplateAsync(RemoveReportTemplateRequest request);

        /// <summary>
        /// 添加词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,UserOrganizationCodeEmpty,ThesaurusNameDuplication</errorCodes>
        Task<bool> AddThesaurusAsync(AddThesaurusRequest request);

        /// <summary>
        /// 更新词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusNameEmpty</errorCodes>
        Task<bool> UpdateThesaurusAsync(UpdateThesaurusRequest request);

        /// <summary>
        /// 添加机构词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,UserOrganizationCodeEmpty,ThesaurusNameDuplication</errorCodes>
        Task<bool> AddOrgThesaurusAsync(AddThesaurusRequest request);

        /// <summary>
        /// 添加词条分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>EditThesaurusItemError,ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> AddThesaurusClassifyAsync(AddThesaurusClassifyRequest request);

        /// <summary>
        /// 添加词条内容
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> AddThesaurusContentAsync(AddThesaurusContentRequest request);

        /// <summary>
        /// 更新词条分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>EditThesaurusItemError,ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> UpdateThesaurusClassifyAsync(UpdateThesaurusClassifyRequest request);

        /// <summary>
        /// 更新词条内容
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> UpdateThesaurusContentAsync(UpdateThesaurusContentRequest request);

        /// <summary>
        /// 删除词条库
        /// </summary>
        /// <param name="request">词条库编码</param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> RemoveThesaurusAsync(RemoveThesaurusRequest request);

        /// <summary>
        /// 删除机构词条库
        /// </summary>
        /// <param name="request">词条库编码</param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,UserNotDirector,AuthenticationError</errorCodes>
        Task<bool> RemoveOrgThesaurusAsync(RemoveThesaurusRequest request);

        /// <summary>
        /// 移除词条项
        /// </summary>
        /// <param name="request">词条项编码</param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> RemoveThesaurusItemAsync(RemoveThesaurusItemRequest request);

        /// <summary>
        /// 获取词条库分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> GetThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取机构词条库分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<PageResult<ThesaurusDTO>> GetOrgThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取词条项列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusItemsAsync(GetThesaurusItemsRequest request);

        /// <summary>
        /// 获取词条项详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ThesaurusItemDTO> GetThesaurusItemByCodeAsync(GetThesaurusItemByCodeRequest request);

        /// <summary>
        /// 根据父级编码获取分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusClassifyByParentCodeAsync(GetThesaurusClassifyByParentCodeRequest request);

        /// <summary>
        /// 根据父级编码获取词条内容
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusContentByParentCodeAsync(GetThesaurusContentByParentCodeRequest request);

        /// <summary>
        /// 拷贝成个人词条库
        /// </summary>
        /// <returns></returns>
        Task<bool> CopyPersonalThesaurusAsync(CopyThesaurusRequest request);

        /// <summary>
        /// 拷贝成机构词条库
        /// </summary>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<bool> CopyOrgThesaurusAsync(CopyOrgThesaurusRequest request);

        /// <summary>
        /// 获取用户默认词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<ThesaurusAllDTO> GetDefaultThesaurusContentAsync(GetDefaultThesaurusContentRequest request);

        /// <summary>
        /// 设置用户默认词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,ThesaurusCodeEmpty</errorCodes>
        Task<bool> SetUserDefaultThesaurusAsync(SetUserDefaultThesaurusRequest request);
        
        /// <summary>
        /// 重发报告转发配置缓存
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<bool> RetryPushReportRecordsAsync(RetryPushReportRecordsByCodesRequest request);
        
        /// <summary>
        /// 查询报告预览图
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> FindReportPreviewImageAsync(FindReportPreviewImageRequest request);
        
        /// <summary>
        /// 查询报告分享地址
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> FindReportShareUrlAsync(FindReportShareUrlRequest request);

        /// <summary>
        /// 获取用户默认报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<ReportTemplateDTO> GetDefaultReportTemplateContentAsync(GetDefaultReportTemplateContentRequest request);

        /// <summary>
        /// 设置用户默认报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,ReportTemplateJsonEmpty</errorCodes>
        Task<bool> SetUserDefaultReportTemplateAsync(SetUserDefaultReportTemplateRequest request);

        /// <summary>
        /// 创建报告模板预览
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateReportTemplatePreviewAsync(GetReportTemplateDBRequest request);
    }
}

==> ReleaseV1.1.3.tar.gz: winginterfacelibrary/src/Interface/IReportService.cs <==
﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.DTO.Report;
using WingInterfaceLibrary.DTO.ReportTemplate;
using WingInterfaceLibrary.DTO.Share;
using WingInterfaceLibrary.Request.Record;
using WingInterfaceLibrary.Request.Report;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 报告服务
    /// </summary>
    /// <docFirstDirectory>报告服务API</docFirstDirectory>
    /// <docSecondDirectory>报告</docSecondDirectory>
    public interface IReportService
    {
        /// <summary>
        /// 查询报告模板详情
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告模板详情</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<ReportTemplateDTO> FindReportTemplateByCodeAsync(FindReportTemplateByCodeRequest request);

        /// <summary>
        /// 查询报告详情
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告详情</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<ReportDTO> FindReportByCodeAsync(FindReportByCodeRequest request);

        /// <summary>
        /// 查询检查关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<List<ReportDTO>> FindExamReportsAsync(FindReportsRequest request);

        /// <summary>
        /// 根据业务编码查询关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<List<ReportDTO>> FindReportsAsync(FindReportsRequest request);

        /// <summary>
        /// 查询病人关联报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<List<ReportDTO>> FindPatientReportsAsync(FindPatientReportsRequest request);

        /// <summary>
        /// 查询报告标签配置
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>报告标签配置集合</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,RecordNotExistError</errorCodes>
        Task<List<ReportLabelDTO>> FindReportLabelsAsync(FindReportLabelsRequest request);

        /// <summary>
        /// 根据分享短码查询分享内容
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>分享记录</returns>
        /// <value></value>
        /// <remarks>POST</remarks>
        Task<ShareDTO> FindShareContentAsync(FindShareContentRequest request);

        /// <summary>
        /// 创建报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,RecordNotExistError,ReportTemplateJsonEmpty,ReportDatasJsonEmpty,AddReportFailed,ReferralRecordNotExisted,ReferralRecordNeverAccepted</errorCodes>
        Task<string> AddReportAsync(AddReportRequest request);

        /// <summary>
        /// 修改报告
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty,RecordNotExistError,ReportTemplateJsonEmpty,ReportDatasJsonEmpty,ReferralRecordNotExisted,ReferralRecordNeverAccepted</errorCodes>
        Task<bool> ModifyReportAsync(ModifyReportRequest request);

        /// <summary>
        /// 修改报告标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>RecordCodeEmpty</errorCodes>
        Task<bool> ModifyReportLabelsAsync(ModifyReportLabelsRequest request);

        /// <summary>
        /// 分享报告-短信
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>ReportCodeEmpty,MobileListEmpty,MessageUrlEmpty,ReportPageNeverConfig,ReportSMSTempalteNeverConfig,CreateShareCodeError</errorCodes>
        Task<bool> ShareReportBySmsAsync(ShareReportBySmsRequest request);

        /// <summary>
        /// 分享报告-邮件
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <errorCodes>ReportCodeEmpty,EmailListEmpty,MessageUrlEmpty,ReportPageNeverConfig,ReportSMSTempalteNeverConfig</errorCodes>
        Task<bool> ShareReportByEmailAsync(ShareReportByEmailRequest request);

        /// <summary>
        /// 拷贝成个人报告模板
        /// </summary>
        /// <returns>模版编码</returns>
        Task<string> CopyPersonalReportTemplateAsync(CopyReportTemplateRequest request);

        /// <summary>
        /// 拷贝成机构报告模板
        /// </summary>
        /// <returns>模版编码</returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<string> CopyOrgReportTemplateAsync(CopyOrgReportTemplateRequest request);

        /// <summary>
        /// 获取报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ReportTemplateDTO>> GetReportTemplatePageAsync(FindReportTemplatePagesRequest request);

        /// <summary>
        /// 获取机构报告模板分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<PageResult<ReportTemplateDTO>> GetOrgReportTemplatePageAsync(FindReportTemplatePagesRequest request);

        /// <summary>
        /// 添加报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>JsonError,AuthenticationError,UserOrganizationCodeEmpty,ReportTemplateNameDuplication</errorCodes>
        Task<string> AddReportTemplateAsync(AddReportTemplateRequest request);

        /// <summary>
        /// 更新报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateReportTemplateAsync(UpdateReportTemplateRequest request);

        /// <summary>
        /// 删除报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ReportTemplateCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> RemoveReportTemplateAsync(RemoveReportTemplateRequest request);

        /// <summary>
        /// 添加机构报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,UserOrganizationCodeEmpty,ReportTemplateNameDuplication</errorCodes>
        Task<string> AddOrgReportTemplateAsync(AddReportTemplateRequest request);

        /// <summary>
        /// 删除机构报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ReportTemplateCodeEmpty,UserNotDirector,AuthenticationError</errorCodes>
        Task<bool> RemoveOrgReportTemplateAsync(RemoveReportTemplateRequest request);

        /// <summary>
        /// 添加词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,UserOrganizationCodeEmpty,ThesaurusNameDuplication</errorCodes>
        Task<bool> AddThesaurusAsync(AddThesaurusRequest request);

        /// <summary>
        /// 更新词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusNameEmpty</errorCodes>
        Task<bool> UpdateThesaurusAsync(UpdateThesaurusRequest request);

        /// <summary>
        /// 添加机构词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,UserOrganizationCodeEmpty,ThesaurusNameDuplication</errorCodes>
        Task<bool> AddOrgThesaurusAsync(AddThesaurusRequest request);

        /// <summary>
        /// 添加词条分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>EditThesaurusItemError,ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> AddThesaurusClassifyAsync(AddThesaurusClassifyRequest request);

        /// <summary>
        /// 添加词条内容
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> AddThesaurusContentAsync(AddThesaurusContentRequest request);

        /// <summary>
        /// 更新词条分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>EditThesaurusItemError,ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> UpdateThesaurusClassifyAsync(UpdateThesaurusClassifyRequest request);

        /// <summary>
        /// 更新词条内容
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> UpdateThesaurusContentAsync(UpdateThesaurusContentRequest request);

        /// <summary>
        /// 删除词条库
        /// </summary>
        /// <param name="request">词条库编码</param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> RemoveThesaurusAsync(RemoveThesaurusRequest request);

        /// <summary>
        /// 删除机构词条库
        /// </summary>
        /// <param name="request">词条库编码</param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,UserNotDirector,AuthenticationError</errorCodes>
        Task<bool> RemoveOrgThesaurusAsync(RemoveThesaurusRequest request);

        /// <summary>
        /// 移除词条项
        /// </summary>
        /// <param name="request">词条项编码</param>
        /// <returns></returns>
        /// <errorCodes>ThesaurusCodeEmpty,AuthenticationError</errorCodes>
        Task<bool> RemoveThesaurusItemAsync(RemoveThesaurusItemRequest request);

        /// <summary>
        /// 获取词条库分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ThesaurusDTO>> GetThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取机构词条库分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<PageResult<ThesaurusDTO>> GetOrgThesaurusPageAsync(GetThesaurusPageRequest request);

        /// <summary>
        /// 获取词条项列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusItemsAsync(GetThesaurusItemsRequest request);

        /// <summary>
        /// 获取词条项详情
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ThesaurusItemDTO> GetThesaurusItemByCodeAsync(GetThesaurusItemByCodeRequest request);

        /// <summary>
        /// 根据父级编码获取分类
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusClassifyByParentCodeAsync(GetThesaurusClassifyByParentCodeRequest request);

        /// <summary>
        /// 根据父级编码获取词条内容
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<ThesaurusItemDTO>> GetThesaurusContentByParentCodeAsync(GetThesaurusContentByParentCodeRequest request);

        /// <summary>
        /// 拷贝成个人词条库
        /// </summary>
        /// <returns></returns>
        Task<bool> CopyPersonalThesaurusAsync(CopyThesaurusRequest request);

        /// <summary>
        /// 拷贝成机构词条库
        /// </summary>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<bool> CopyOrgThesaurusAsync(CopyOrgThesaurusRequest request);

        /// <summary>
        /// 获取用户默认词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError</errorCodes>
        Task<ThesaurusAllDTO> GetDefaultThesaurusContentAsync(GetDefaultThesaurusContentRequest request);

        /// <summary>
        /// 设置用户默认词条库
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,ThesaurusCodeEmpty</errorCodes>
        Task<bool> SetUserDefaultThesaurusAsync(SetUserDefaultThesaurusRequest request);

        /// <summary>
        /// 重发报告转发配置缓存
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<bool> RetryPushReportRecordsAsync(RetryPushReportRecordsByCodesRequest request);

        /// <summary>
        /// 查询报告预览图
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <show>false</show>
        Task<string> FindReportPreviewImageAsync(FindReportPreviewImageRequest request);

        /// <summary>
        /// 查询报告分享地址
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<string> FindReportShareUrlAsync(FindReportShareUrlRequest request);

        /// <summary>
        /// 获取用户默认报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,NotSetDefaultReportTemplate</errorCodes>
        Task<ReportTemplateDTO> GetDefaultReportTemplateContentAsync(GetDefaultReportTemplateContentRequest request);

        /// <summary>
        /// 设置用户默认报告模板
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>AuthenticationError,ReportTemplateJsonEmpty</errorCodes>
        Task<bool> SetUserDefaultReportTemplateAsync(SetUserDefaultReportTemplateRequest request);

        /// <summary>
        /// 创建报告模板预览
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateReportTemplatePreviewAsync(GetReportTemplateDBRequest request);

        /// <summary>
        /// 检查报告模板名称是否可用 
        /// </summary>
        /// <param name="request"></param>
        /// <returns>true</returns>
        Task<bool> CheckReportTemplateName(UpdateReportTemplateRequest request);
    }
}
